<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateProductsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('products', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->unsignedBigInteger('container_id');
            $table->string('sku')->index();
            $table->char('manufacturer_country', 2)->index();
            $table->string('product_name')->index();
            $table->string('image')->nullable();
            $table->unsignedDecimal('price')->index()->default(0);
            $table->boolean('can_preorder')->index()->default(true)->nullable();
            $table->boolean('can_gift')->index()->default(false)->nullable();
            $table->unsignedBigInteger('manufacture_id');
            $table->unsignedDecimal('product_weight')->index()->nullable();
            $table->unsignedDecimal('product_width')->index()->nullable();
            $table->unsignedDecimal('product_height')->index()->nullable();
            $table->unsignedDecimal('product_length')->index()->nullable();

            $table->timestamps();
        });
        Schema::table('products', function (Blueprint $table) {
            $table->unique(['container_id', 'sku', 'manufacture_id']);
            $table->foreign('container_id')->on('containers')->references('id');
            $table->foreign('manufacture_id')->on('manufactures')->references('id');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('products');
    }
}
