<?php

use Illuminate\Support\HtmlString;

if (!defined('TDEV_AGENCY_ERP_ROOT')) {
    define('TDEV_AGENCY_ERP_ROOT', __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR);
}

if (!defined('selectCurrency')) {
    function selectCurrency()
    {
        $options = [];
        $currencies = Config::get('erp.currencies');
        foreach ($currencies as $index => $data) {
            $options[$index] = $data['name'];
        }

        return $options;
    }
}

if (!function_exists('mixErp')) {
    /**
     * @param $path
     * @return HtmlString|string
     * @throws Exception
     */
    function mixErp($path)
    {
        $manifestDirectory = TDEV_AGENCY_ERP_ROOT . 'public';


        static $manifests = [];

        if (!Str::startsWith($path, '/')) {
            $path = "/{$path}";
        }

        if ($manifestDirectory && !Str::startsWith($manifestDirectory, '/')) {
            $manifestDirectory = "/{$manifestDirectory}";
        }

        if (file_exists(public_path($manifestDirectory . '/hot'))) {
            $url = rtrim(file_get_contents(public_path($manifestDirectory . '/hot')));

            if (Str::startsWith($url, ['http://', 'https://'])) {
                return new HtmlString(Str::after($url, ':') . $path);
            }

            return new HtmlString("//localhost:8080{$path}");
        }

        $manifestPath = $manifestDirectory . '/mix-manifest.json';

        if (!isset($manifests[$manifestPath])) {
            if (!file_exists($manifestPath)) {
                throw new Exception('The Mix manifest does not exist.');
            }

            $manifests[$manifestPath] = json_decode(file_get_contents($manifestPath), true);
        }

        $manifest = $manifests[$manifestPath];

        if (!isset($manifest[$path])) {
            $exception = new Exception("Unable to locate Mix file: {$path}.");

            if (!app('config')->get('app.debug')) {
                report($exception);

                return $path;
            } else {
                throw $exception;
            }
        }

        return new HtmlString(app('config')->get('app.mix_url') . '/erp' . $manifest[$path]);
    }
}
